package com.zhaitech.lilith.commons.domain;

import javax.persistence.*;
import java.io.Serializable;
import java.util.Date;
import java.util.UUID;

@MappedSuperclass
@EntityListeners({BaseEntity.BaseEntityListener.class})
public abstract class BaseEntity implements Serializable {

    private static final long serialVersionUID = -1;

    @Id
    @GeneratedValue(strategy=GenerationType.SEQUENCE)
    public Long id;

    private UUID uid;

    @Temporal(TemporalType.TIMESTAMP)
    public Date created;

    @Temporal(TemporalType.TIMESTAMP)
    public Date updated;

    public long version;

    //*************************************************************************
    // Entity Listener Methods
    //*************************************************************************

    public static class BaseEntityListener {

        @PrePersist
        public void onPrePersist(BaseEntity baseEntity) {
            if (baseEntity.uid == null) baseEntity.uid = UUID.randomUUID();
            baseEntity.created = new Date();
            baseEntity.updated = new Date();
            baseEntity.version++;
        }

        @PreUpdate
        public void onPreUpdate(BaseEntity baseEntity) {
            baseEntity.updated = new Date();
            baseEntity.version++;
        }
    }

}
