package com.zhaitech.lilith.commons.test;

import com.google.inject.persist.Transactional;
import com.zhaitech.lilith.commons.test.domain.Company;
import org.junit.Test;
import org.junit.runner.RunWith;

import javax.inject.Inject;
import javax.persistence.EntityManager;
import javax.persistence.Query;

@RunWith(TestRunner.class)
public class CRUDTest {

    @Inject
    private EntityManager em;

    @Transactional
    @Test
    public void testCRUD() throws Exception {
        // test creation
        Company newCompany = new Company();
        newCompany.name = "testUser";
        newCompany.description = "testUser";
        newCompany.domain = "testUser";
        em.persist(newCompany);
        em.flush();
        assert newCompany.id != 0;

        // test update
        newCompany.name = "testUserModified";
        em.persist(newCompany);
        em.flush();
        assert newCompany.id != null;

        // test query
        Company updatedCompany = em.find(Company.class, newCompany.id);
        assert updatedCompany != null;
        assert updatedCompany.name.equals("testUserModified");

        // test delete
        em.remove(updatedCompany);
        Company removedUser = em.find(Company.class, newCompany.id);
        assert removedUser == null;
        assert !em.contains(newCompany);
    }

    @Transactional
    @Test
    public void testExecuteUpdate() {
        em.createQuery("DELETE FROM Company").executeUpdate();
        em.createQuery("DELETE FROM Employee").executeUpdate();
    }
}
