package com.zhaitech.lilith.commons.test;

import com.google.inject.Injector;
import com.google.inject.Module;
import com.google.inject.persist.PersistService;
import com.google.inject.persist.jpa.JpaPersistModule;
import org.junit.runners.BlockJUnit4ClassRunner;
import org.junit.runners.model.InitializationError;

import java.io.InputStream;
import java.util.ArrayList;
import java.util.List;
import java.util.Properties;

import static com.google.inject.Guice.createInjector;

public class TestRunner extends BlockJUnit4ClassRunner {

    private Injector injector;

    public TestRunner(Class<?> klass) throws InitializationError {
        super(klass);

        List<Module> modules = new ArrayList<>();
        Properties dbProp = loadProperties("db_redis.properties");
        modules.add(new JpaPersistModule(dbProp.getProperty("jpa.unit.name"))
                .properties(dbProp));

        injector = createInjector(modules);
        injector.getInstance(PersistService.class).start();
    }

    @Override
    protected final Object createTest() throws Exception {
        return injector.getInstance(this.getTestClass().getJavaClass());
    }

    public Properties loadProperties(String propFile) {
        if (!propFile.startsWith("/")) propFile = "/"+propFile;
        final Properties prop = new Properties();
        InputStream in = null;
        try {
            in = getClass().getResourceAsStream(propFile);
            prop.load(in);
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            try {
                in.close();
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
        return prop;
    }
}

